==> core-image-1.3.1-sources.jar: org/openimaj/image/processor/ImageProcessor.java <==
/**
 * Copyright (c) 2011, The University of Southampton and the individual contributors.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 *   * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 *
 *   *	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 *
 *   *	Neither the name of the University of Southampton nor the names of its
 * 	contributors may be used to endorse or promote products derived from this
 * 	software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.openimaj.image.processor;

import org.openimaj.image.Image;
import org.openimaj.image.analyser.ImageAnalyser;

/**
 * 	An interface for objects that are able to process whole images. The
 * 	processing must be performed in-place; that is, the input image is
 * 	side-affected by the processing.
 *  <p>
 *  If you don't want to alter the image content, use an {@link ImageAnalyser}
 *  instead.
 * 
 *  @author Jonathon Hare (jsh2@ecs.soton.ac.uk)
 *  @param <I> The type of image that this processor can process
 */
public interface ImageProcessor<I extends Image<?,I>> extends Processor<I> 
{
	/**
	 * Process an image. Implementing classes must alter the image passed in-place
	 * or assign the output to the input using {@link Image#internalAssign(Image)}.
	 * 
	 * @param image The image to process in place.
	 */
	public abstract void processImage(I image);
}

==> core-image-1.3.5-sources.jar: org/openimaj/image/processor/ImageProcessor.java <==
/**
 * Copyright (c) 2011, The University of Southampton and the individual contributors.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 *   * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 *
 *   *	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 *
 *   *	Neither the name of the University of Southampton nor the names of its
 * 	contributors may be used to endorse or promote products derived from this
 * 	software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.openimaj.image.processor;

import org.openimaj.image.Image;
import org.openimaj.image.analyser.ImageAnalyser;

/**
 * An interface for objects that are able to process whole images. The
 * processing must be performed in-place; that is, the input image is
 * side-affected by the processing.
 * <p>
 * If you don't want to alter the image content, use an {@link ImageAnalyser}
 * instead.
 *
 * @author Jonathon Hare (jsh2@ecs.soton.ac.uk)
 * @param <I>
 *            The type of image that this processor can process
 */
public interface ImageProcessor<I extends Image<?, I>> extends Processor<I>
{
	/**
	 * Process an image. Implementing classes must alter the image passed
	 * in-place or assign the output to the input using
	 * {@link Image#internalAssign(Image)}.
	 *
	 * @param image
	 *            The image to process in place.
	 */
	public abstract void processImage(I image);
}
